﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
//using System.Threading.Tasks;
using System.Windows.Forms;
using Phidget22;
using Phidget22.Events;
using Phidget22.ExampleUtils;

namespace PowerGuard_Example {
	public partial class Form1 : Form {
		CommandLineOpen openArgs;
		PowerGuard openCh = null;
		formCleaner cleaner;
		PowerGuard powerGuard = null;
		private ErrorEventBox errorBox;

		public Form1() {
			InitializeComponent();
			openArgs = new CommandLineOpen(this);
			cleaner = new formCleaner(this);
		}

		public Form1(PowerGuard ch) {
			InitializeComponent();
			openCh = ch;
			cleaner = new formCleaner(this);
		}

		private void Form1_Load(object sender, EventArgs e) {
			fanCombo.DataSource = typeof(FanMode).ToList();
			fanCombo.SelectedIndex = -1;

			errorBox = new ErrorEventBox(this);
			powerGuard = openCh ?? openArgs.makeChannel<PowerGuard>();

			powerGuard.Attach += powerGuard_attach;
			powerGuard.Detach += powerGuard_detach;
			powerGuard.Error += powerGuard_error;

			try {
				powerGuard.Open();
			} catch (PhidgetException ex) { errorBox.addMessage("Error opening device: " + ex.Message); }
		}

		private void Form1_FormClosing(object sender, FormClosingEventArgs e) {

			powerGuard.Attach -= powerGuard_attach;
			powerGuard.Detach -= powerGuard_detach;
			powerGuard.Error -= powerGuard_error;
			powerGuard.Close();
		}

		void powerGuard_attach(object sender, Phidget22.Events.AttachEventArgs e) {
			phidgetInfoBox1.FillPhidgetInfo((Phidget)sender);

			settingsBox.Visible = true;

			try {
				fanCombo.SelectedIndex = 0;
				powerGuard.OverVoltage = overVoltageTrk.Value;
				powerGuard.PowerEnabled = enablechk.Checked;
			} catch (PhidgetException ex) { errorBox.addMessage("Error initializing device: " + ex.Message); }

		}

		void powerGuard_detach(object sender, Phidget22.Events.DetachEventArgs e) {
			phidgetInfoBox1.Clear();
			cleaner.clean();

			settingsBox.Visible = false;
		}

		void powerGuard_error(object sender, Phidget22.Events.ErrorEventArgs e) {
			errTxt.Text = e.Description;
			errorBox.addMessage(e.Description);
		}


		private void overVoltage_Scroll(object sender, EventArgs e) {
			try {
				powerGuard.OverVoltage = overVoltageTrk.Value;
				overVoltageTxt.Text = powerGuard.OverVoltage.ToString();
			} catch (PhidgetException ex) { MessageBox.Show(ex.ToString()); }
		}

		private void enablechk_CheckedChanged(object sender, EventArgs e) {
			try {
				powerGuard.PowerEnabled = enablechk.Checked;
			} catch (PhidgetException ex) { MessageBox.Show(ex.ToString()); }
		}

		private void fanCombo_SelectedIndexChanged(object sender, EventArgs e) {
			if (((ComboBox)sender).SelectedIndex == -1 || powerGuard == null)
				return;
			try {
				powerGuard.FanMode = (FanMode)Enum.Parse(typeof(FanMode), fanCombo.SelectedValue.ToString());
			} catch (PhidgetException ex) { errorBox.addMessage("Error setting fan mode: " + ex.Message); }
		}


	}
}
